/**
 * The controller of the favorites template..
 * @param {Object} $templateViewElement - the root element of the template.
 * @param {Object} templateMetaData - parameters for the initialization of the twitter model.
 * @param {Object} templateId - the template ID to use with the API context.
 * @param {Object} cbPageSelected - callback to tell the template that one of the inner pages was selected.
 */
var FavoritesControl = function($templateViewElement, templateMetaData, templateId, cbPageSelected)
{
    var me = {};
    
    // The main page
    var _homePageView;
    
    /**
     * Initialize the controller.
     * @param {Object} $templateViewElement - the root element of the template.
     * @param {Object} templateMetaData - parameters for the initialization of the twitter model.
     * @param {Object} templateId - the template ID to use with the API context.
     * @param {Object} cbPageSelected - callback to tell the template that one of the inner pages was selected.
     */
    me.init = function($templateViewElement, templateMetaData, templateId)
    {
        var layoutId = templateMetaData.pageLayout;
        var template = favoritesTemplates[layoutId];
        if (!template) 
        {
            template = favoritesTemplates['1']; // Default template
        }
        
        var model = new FavoritesModel(
        {
            tracks: templateMetaData,
            templateId: templateId
        });
        
        _homePageView = new FavoritesView(
        {
            model: model,
            template: template
        });
        
        // add the home page to the template container.
        $templateViewElement.append(_homePageView.render().el);
        
        // Bind page event
        $('#' + _homePageView.id).bind('pageshow', this.onPageShow.hitch(this));
    };
    
    /**
     * Function necessary for the template view to display the page when tab is selected
     *
     * @author Moshe Darzi
     */
    me.getChangePageParams = function()
    {
        return _homePageView.getChangePageParams();
    };
    
	/**
	 * Update home page when this tab is selected
	 * 
	 * @author Moshe Darzi
	 */
    me.onPageShow = function()
    {
        // Redraw the view to display the changes if occured
		_homePageView.redraw();
    }
    
    me.init($templateViewElement, templateMetaData, templateId);
    
    return me;
};

var controllerName = 'FavoritesControl';
